@@ -123,3 +123,25 @@ def test_sub_process_not_defined_in_process_type():
 
     assert 'Provided sub process is not defined in ProcessType.' in \
         str(exception)
+
+
+def test_invalid_telemetry_type():
+    """ test InvalidTelemetryType exception """
+    with pytest.raises(
+            exceptions.InvalidTelemetryType) as exception:
+        raise exceptions.InvalidTelemetryType(['type1', 'type2'])
+
+    assert 'Telemetry Type must be of type: type1' in \
+        str(exception)
+
+
+def test_class_telemetry_params_not_defined():
+    """ test ClassTelemetryParamsNotDefined exception """
+    obj = 'object'
+    with pytest.raises(
+            exceptions.ClassTelemetryParamsNotDefined) as exception:
+        raise exceptions.ClassTelemetryParamsNotDefined(obj)
+
+    assert \
+        f"Telemetry params not defined for class {obj.__class__.__name__}" in \
+        str(exception)
